@@ -27,6 +27,7 @@
 """
 
 import email.utils
+import inspect
 import uuid
 
 from django.conf import settings
@@ -35,7 +36,6 @@ from django.contrib.auth import authenticate
 from django.contrib.auth import get_user_model
 from django.contrib.auth import login
 from django.core.mail import EmailMessage
-from django.core.urlresolvers import reverse
 from django.http import Http404
 from django.shortcuts import redirect
 from django.shortcuts import render
@@ -45,6 +45,7 @@ from django.utils.translation import ugettext as _
 from organizations.backends.forms import UserRegistrationForm
 from organizations.backends.forms import org_registration_form
 from organizations.backends.tokens import RegistrationTokenGenerator
+from organizations.compat import reverse
 from organizations.utils import create_organization
 from organizations.utils import default_org_model
 from organizations.utils import model_field_attr
@@ -135,13 +136,15 @@ class BaseBackend(object):
             return False
         token = RegistrationTokenGenerator().make_token(user)
         kwargs.update({'token': token})
-        self._send_email(user, self.reminder_subject, self.reminder_body, sender, **kwargs)
+        self.email_message(user, self.reminder_subject, self.reminder_body, sender, **kwargs).send()
 
-    # This could be replaced with a more channel agnostic function, most likely
-    # in a custom backend.
-    def _send_email(self, user, subject_template, body_template,
-            sender=None, **kwargs):
-        """Utility method for sending emails to new users"""
+    def email_message(self, user, subject_template, body_template,
+            sender=None, message_class=EmailMessage, **kwargs):
+        """
+        Returns an email message for a new user. This can be easily overriden.
+        For instance, to send an HTML message, use the EmailMultiAlternatives message_class
+        and attach the additional conent.
+        """
         if sender:
             from_email = "%s %s <%s>" % (sender.first_name, sender.last_name,
                     email.utils.parseaddr(settings.DEFAULT_FROM_EMAIL)[1])
@@ -157,7 +160,7 @@ class BaseBackend(object):
         body_template = loader.get_template(body_template)
         subject = subject_template.render(kwargs).strip()  # Remove stray newline characters
         body = body_template.render(kwargs)
-        return EmailMessage(subject, body, from_email, [user.email], headers=headers).send()
+        return message_class(subject, body, from_email, [user.email], headers=headers)
 
 
 class RegistrationBackend(BaseBackend):
@@ -208,14 +211,18 @@ class RegistrationBackend(BaseBackend):
             return False
         token = self.get_token(user)
         kwargs.update({'token': token})
-        self._send_email(user, self.activation_subject, self.activation_body, sender, **kwargs)
+        self.email_message(user, self.activation_subject, self.activation_body, sender, **kwargs).send()
 
     def create_view(self, request):
         """
         Initiates the organization and user account creation process
         """
-        if request.user.is_authenticated():
-            return redirect("organization_add")
+        try:
+            if request.user.is_authenticated():
+                return redirect("organization_add")
+        except TypeError:
+            if request.user.is_authenticated:
+                return redirect("organization_add")
         form = org_registration_form(self.org_model)(request.POST or None)
         if form.is_valid():
             try:
@@ -272,8 +279,12 @@ class InvitationBackend(BaseBackend):
             user = self.user_model.objects.get(email=email)
         except self.user_model.DoesNotExist:
             # TODO break out user creation process
-            user = self.user_model.objects.create(username=self.get_username(),
-                    email=email, password=self.user_model.objects.make_random_password())
+            if 'username' in inspect.getargspec(self.user_model.objects.create_user).args:
+                user = self.user_model.objects.create(username=self.get_username(),
+                        email=email, password=self.user_model.objects.make_random_password())
+            else:
+                user = self.user_model.objects.create(email=email,
+                        password=self.user_model.objects.make_random_password())
             user.is_active = False
             user.save()
         self.send_invitation(user, sender, **kwargs)
@@ -288,7 +299,7 @@ class InvitationBackend(BaseBackend):
             return False
         token = self.get_token(user)
         kwargs.update({'token': token})
-        self._send_email(user, self.invitation_subject, self.invitation_body, sender, **kwargs)
+        self.email_message(user, self.invitation_subject, self.invitation_body, sender, **kwargs).send()
         return True
 
     def send_notification(self, user, sender=None, **kwargs):
@@ -299,5 +310,5 @@ class InvitationBackend(BaseBackend):
         """
         if not user.is_active:
             return False
-        self._send_email(user, self.notification_subject, self.notification_body, sender, **kwargs)
+        self.email_message(user, self.notification_subject, self.notification_body, sender, **kwargs).send()
         return True
