@@ -24,7 +24,6 @@
 # OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 from django.contrib.sites.shortcuts import get_current_site
-from django.core.urlresolvers import reverse
 from django.http import HttpResponseBadRequest
 from django.shortcuts import redirect
 from django.shortcuts import render
@@ -38,6 +37,7 @@ from django.views.generic import UpdateView
 
 from organizations.backends import invitation_backend
 from organizations.backends import registration_backend
+from organizations.compat import reverse
 from organizations.forms import OrganizationAddForm
 from organizations.forms import OrganizationForm
 from organizations.forms import OrganizationUserAddForm
@@ -177,8 +177,12 @@ class OrganizationSignup(FormView):
     backend = registration_backend()
 
     def dispatch(self, request, *args, **kwargs):
-        if request.user.is_authenticated():
-            return redirect('organization_add')
+        try:
+            if request.user.is_authenticated():
+                return redirect('organization_add')
+        except TypeError:
+            if request.user.is_authenticated:
+                return redirect('organization_add')
         return super(OrganizationSignup, self).dispatch(request, *args,
                 **kwargs)
 
